==> StanHeaders_2.12.0-1.tar.gz: StanHeaders/inst/include/stan/math/fwd/scal.hpp <==
#ifndef STAN_MATH_FWD_SCAL_HPP
#define STAN_MATH_FWD_SCAL_HPP

#include <stan/math/fwd/core.hpp>
#include <stan/math/fwd/scal/meta/is_fvar.hpp>
#include <stan/math/fwd/scal/meta/partials_type.hpp>
#include <stan/math/fwd/scal/meta/OperandsAndPartials.hpp>

#include <stan/math/prim/scal.hpp>

#include <stan/math/fwd/scal/fun/Phi.hpp>
#include <stan/math/fwd/scal/fun/abs.hpp>
#include <stan/math/fwd/scal/fun/acos.hpp>
#include <stan/math/fwd/scal/fun/acosh.hpp>
#include <stan/math/fwd/scal/fun/asin.hpp>
#include <stan/math/fwd/scal/fun/asinh.hpp>
#include <stan/math/fwd/scal/fun/atan.hpp>
#include <stan/math/fwd/scal/fun/atan2.hpp>
#include <stan/math/fwd/scal/fun/atanh.hpp>
#include <stan/math/fwd/scal/fun/bessel_first_kind.hpp>
#include <stan/math/fwd/scal/fun/bessel_second_kind.hpp>
#include <stan/math/fwd/scal/fun/binary_log_loss.hpp>
#include <stan/math/fwd/scal/fun/binomial_coefficient_log.hpp>
#include <stan/math/fwd/scal/fun/cbrt.hpp>
#include <stan/math/fwd/scal/fun/ceil.hpp>
#include <stan/math/fwd/scal/fun/cos.hpp>
#include <stan/math/fwd/scal/fun/cosh.hpp>
#include <stan/math/fwd/scal/fun/digamma.hpp>
#include <stan/math/fwd/scal/fun/erf.hpp>
#include <stan/math/fwd/scal/fun/erfc.hpp>
#include <stan/math/fwd/scal/fun/exp.hpp>
#include <stan/math/fwd/scal/fun/exp2.hpp>
#include <stan/math/fwd/scal/fun/expm1.hpp>
#include <stan/math/fwd/scal/fun/fabs.hpp>
#include <stan/math/fwd/scal/fun/falling_factorial.hpp>
#include <stan/math/fwd/scal/fun/fdim.hpp>
#include <stan/math/fwd/scal/fun/floor.hpp>
#include <stan/math/fwd/scal/fun/fma.hpp>
#include <stan/math/fwd/scal/fun/fmax.hpp>
#include <stan/math/fwd/scal/fun/fmin.hpp>
#include <stan/math/fwd/scal/fun/fmod.hpp>
#include <stan/math/fwd/scal/fun/gamma_p.hpp>
#include <stan/math/fwd/scal/fun/gamma_q.hpp>
#include <stan/math/fwd/scal/fun/grad_inc_beta.hpp>
#include <stan/math/fwd/scal/fun/hypot.hpp>
#include <stan/math/fwd/scal/fun/inc_beta.hpp>
#include <stan/math/fwd/scal/fun/inv.hpp>
#include <stan/math/fwd/scal/fun/inv_Phi.hpp>
#include <stan/math/fwd/scal/fun/inv_cloglog.hpp>
#include <stan/math/fwd/scal/fun/inv_logit.hpp>
#include <stan/math/fwd/scal/fun/inv_sqrt.hpp>
#include <stan/math/fwd/scal/fun/inv_square.hpp>
#include <stan/math/fwd/scal/fun/is_inf.hpp>
#include <stan/math/fwd/scal/fun/is_nan.hpp>
#include <stan/math/fwd/scal/fun/lbeta.hpp>
#include <stan/math/fwd/scal/fun/lgamma.hpp>
#include <stan/math/fwd/scal/fun/lmgamma.hpp>
#include <stan/math/fwd/scal/fun/log.hpp>
#include <stan/math/fwd/scal/fun/log10.hpp>
#include <stan/math/fwd/scal/fun/log1m.hpp>
#include <stan/math/fwd/scal/fun/log1m_exp.hpp>
#include <stan/math/fwd/scal/fun/log1m_inv_logit.hpp>
#include <stan/math/fwd/scal/fun/log1p.hpp>
#include <stan/math/fwd/scal/fun/log1p_exp.hpp>
#include <stan/math/fwd/scal/fun/log2.hpp>
#include <stan/math/fwd/scal/fun/log_diff_exp.hpp>
#include <stan/math/fwd/scal/fun/log_falling_factorial.hpp>
#include <stan/math/fwd/scal/fun/log_inv_logit.hpp>
#include <stan/math/fwd/scal/fun/log_mix.hpp>
#include <stan/math/fwd/scal/fun/log_rising_factorial.hpp>
#include <stan/math/fwd/scal/fun/log_sum_exp.hpp>
#include <stan/math/fwd/scal/fun/logit.hpp>
#include <stan/math/fwd/scal/fun/modified_bessel_first_kind.hpp>
#include <stan/math/fwd/scal/fun/modified_bessel_second_kind.hpp>
#include <stan/math/fwd/scal/fun/multiply_log.hpp>
#include <stan/math/fwd/scal/fun/owens_t.hpp>
#include <stan/math/fwd/scal/fun/pow.hpp>
#include <stan/math/fwd/scal/fun/primitive_value.hpp>
#include <stan/math/fwd/scal/fun/rising_factorial.hpp>
#include <stan/math/fwd/scal/fun/round.hpp>
#include <stan/math/fwd/scal/fun/sin.hpp>
#include <stan/math/fwd/scal/fun/sinh.hpp>
#include <stan/math/fwd/scal/fun/sqrt.hpp>
#include <stan/math/fwd/scal/fun/square.hpp>
#include <stan/math/fwd/scal/fun/tan.hpp>
#include <stan/math/fwd/scal/fun/tanh.hpp>
#include <stan/math/fwd/scal/fun/tgamma.hpp>
#include <stan/math/fwd/scal/fun/to_fvar.hpp>
#include <stan/math/fwd/scal/fun/trunc.hpp>
#include <stan/math/fwd/scal/fun/value_of.hpp>
#include <stan/math/fwd/scal/fun/value_of_rec.hpp>

#endif

==> StanHeaders_2.17.1.tar.gz: StanHeaders/inst/include/stan/math/fwd/scal.hpp <==
#ifndef STAN_MATH_FWD_SCAL_HPP
#define STAN_MATH_FWD_SCAL_HPP

#include <stan/math/fwd/core.hpp>
#include <stan/math/fwd/scal/meta/ad_promotable.hpp>
#include <stan/math/fwd/scal/meta/is_fvar.hpp>
#include <stan/math/fwd/scal/meta/partials_type.hpp>
#include <stan/math/fwd/scal/meta/operands_and_partials.hpp>

#include <stan/math/prim/scal.hpp>

#include <stan/math/fwd/scal/fun/Phi.hpp>
#include <stan/math/fwd/scal/fun/abs.hpp>
#include <stan/math/fwd/scal/fun/acos.hpp>
#include <stan/math/fwd/scal/fun/acosh.hpp>
#include <stan/math/fwd/scal/fun/asin.hpp>
#include <stan/math/fwd/scal/fun/asinh.hpp>
#include <stan/math/fwd/scal/fun/atan.hpp>
#include <stan/math/fwd/scal/fun/atan2.hpp>
#include <stan/math/fwd/scal/fun/atanh.hpp>
#include <stan/math/fwd/scal/fun/bessel_first_kind.hpp>
#include <stan/math/fwd/scal/fun/bessel_second_kind.hpp>
#include <stan/math/fwd/scal/fun/binary_log_loss.hpp>
#include <stan/math/fwd/scal/fun/binomial_coefficient_log.hpp>
#include <stan/math/fwd/scal/fun/cbrt.hpp>
#include <stan/math/fwd/scal/fun/ceil.hpp>
#include <stan/math/fwd/scal/fun/cos.hpp>
#include <stan/math/fwd/scal/fun/cosh.hpp>
#include <stan/math/fwd/scal/fun/digamma.hpp>
#include <stan/math/fwd/scal/fun/erf.hpp>
#include <stan/math/fwd/scal/fun/erfc.hpp>
#include <stan/math/fwd/scal/fun/exp.hpp>
#include <stan/math/fwd/scal/fun/exp2.hpp>
#include <stan/math/fwd/scal/fun/expm1.hpp>
#include <stan/math/fwd/scal/fun/fabs.hpp>
#include <stan/math/fwd/scal/fun/falling_factorial.hpp>
#include <stan/math/fwd/scal/fun/fdim.hpp>
#include <stan/math/fwd/scal/fun/floor.hpp>
#include <stan/math/fwd/scal/fun/fma.hpp>
#include <stan/math/fwd/scal/fun/fmax.hpp>
#include <stan/math/fwd/scal/fun/fmin.hpp>
#include <stan/math/fwd/scal/fun/fmod.hpp>
#include <stan/math/fwd/scal/fun/gamma_p.hpp>
#include <stan/math/fwd/scal/fun/gamma_q.hpp>
#include <stan/math/fwd/scal/fun/grad_inc_beta.hpp>
#include <stan/math/fwd/scal/fun/hypot.hpp>
#include <stan/math/fwd/scal/fun/inc_beta.hpp>
#include <stan/math/fwd/scal/fun/inv.hpp>
#include <stan/math/fwd/scal/fun/inv_Phi.hpp>
#include <stan/math/fwd/scal/fun/inv_cloglog.hpp>
#include <stan/math/fwd/scal/fun/inv_logit.hpp>
#include <stan/math/fwd/scal/fun/inv_sqrt.hpp>
#include <stan/math/fwd/scal/fun/inv_square.hpp>
#include <stan/math/fwd/scal/fun/is_inf.hpp>
#include <stan/math/fwd/scal/fun/is_nan.hpp>
#include <stan/math/fwd/scal/fun/lbeta.hpp>
#include <stan/math/fwd/scal/fun/lgamma.hpp>
#include <stan/math/fwd/scal/fun/lmgamma.hpp>
#include <stan/math/fwd/scal/fun/log.hpp>
#include <stan/math/fwd/scal/fun/log10.hpp>
#include <stan/math/fwd/scal/fun/log1m.hpp>
#include <stan/math/fwd/scal/fun/log1m_exp.hpp>
#include <stan/math/fwd/scal/fun/log1m_inv_logit.hpp>
#include <stan/math/fwd/scal/fun/log1p.hpp>
#include <stan/math/fwd/scal/fun/log1p_exp.hpp>
#include <stan/math/fwd/scal/fun/log2.hpp>
#include <stan/math/fwd/scal/fun/log_diff_exp.hpp>
#include <stan/math/fwd/scal/fun/log_falling_factorial.hpp>
#include <stan/math/fwd/scal/fun/log_inv_logit.hpp>
#include <stan/math/fwd/scal/fun/log_mix.hpp>
#include <stan/math/fwd/scal/fun/log_rising_factorial.hpp>
#include <stan/math/fwd/scal/fun/log_sum_exp.hpp>
#include <stan/math/fwd/scal/fun/logit.hpp>
#include <stan/math/fwd/scal/fun/modified_bessel_first_kind.hpp>
#include <stan/math/fwd/scal/fun/modified_bessel_second_kind.hpp>
#include <stan/math/fwd/scal/fun/multiply_log.hpp>
#include <stan/math/fwd/scal/fun/owens_t.hpp>
#include <stan/math/fwd/scal/fun/Phi_approx.hpp>
#include <stan/math/fwd/scal/fun/pow.hpp>
#include <stan/math/fwd/scal/fun/primitive_value.hpp>
#include <stan/math/fwd/scal/fun/rising_factorial.hpp>
#include <stan/math/fwd/scal/fun/round.hpp>
#include <stan/math/fwd/scal/fun/sin.hpp>
#include <stan/math/fwd/scal/fun/sinh.hpp>
#include <stan/math/fwd/scal/fun/sqrt.hpp>
#include <stan/math/fwd/scal/fun/square.hpp>
#include <stan/math/fwd/scal/fun/tan.hpp>
#include <stan/math/fwd/scal/fun/tanh.hpp>
#include <stan/math/fwd/scal/fun/tgamma.hpp>
#include <stan/math/fwd/scal/fun/to_fvar.hpp>
#include <stan/math/fwd/scal/fun/trigamma.hpp>
#include <stan/math/fwd/scal/fun/trunc.hpp>
#include <stan/math/fwd/scal/fun/value_of.hpp>
#include <stan/math/fwd/scal/fun/value_of_rec.hpp>

#endif
